@@ -117,7 +117,7 @@ class Evaluator:
         for the given series frequency as returned by `get_seasonality`
     alpha
         Parameter of the MSIS metric from the M4 competition that
-        defines the confidence interval.
+        defines the prediction interval.
         For alpha=0.05 (default) the 95% considered is considered in the
         metric, see
         https://www.m4.unic.ac.cy/wp-content/uploads/2018/03/M4-Competitors-Guide.pdf
@@ -134,7 +134,7 @@ class Evaluator:
         First, a callable which takes as input target and forecast and
         returns the evaluation metric.
         Second, a string specifying the aggregation metric across all
-        time-series, f.e. "mean", "sum".
+        time series, f.e. "mean", "sum".
         Third, either "mean" or "median" to specify whether mean or median
         forecast should be passed to the custom evaluation function.
         E.g. {"RMSE": [rmse, "mean", "median"]}
@@ -203,7 +203,7 @@ class Evaluator:
         dict
             Dictionary of aggregated metrics
         pd.DataFrame
-            DataFrame containing per-time-series metrics
+            DataFrame containing metrics per time series
         """
         ts_iterator = iter(ts_iterator)
         fcst_iterator = iter(fcst_iterator)
@@ -255,7 +255,7 @@ class Evaluator:
             {
                 col: np.float64
                 for col in metrics_per_ts.columns
-                if col != "item_id"
+                if col not in ["item_id", "forecast_start"]
             }
         )
 
@@ -347,6 +347,7 @@ class Evaluator:
 
         metrics: Dict[str, Union[float, str, None]] = {
             "item_id": forecast.item_id,
+            "forecast_start": forecast.start_date,
             "MSE": mse(pred_target, mean_fcst)
             if mean_fcst is not None
             else None,
@@ -542,7 +543,7 @@ class MultivariateEvaluator(Evaluator):
         quantiles: Iterable[Union[float, str]] = np.linspace(0.1, 0.9, 9),
         seasonality: Optional[int] = None,
         alpha: float = 0.05,
-        eval_dims: List[int] = None,
+        eval_dims: Optional[List[int]] = None,
         target_agg_funcs: Dict[str, Callable] = {},
         custom_eval_fn: Optional[dict] = None,
         num_workers: Optional[int] = None,
