@@ -11,12 +11,16 @@
 # express or implied. See the License for the specific language governing
 # permissions and limitations under the License.
 
-# Relative imports
-from ._estimator import DeepAREstimator
+import warnings
+
+from gluonts.mx.model.deepar import DeepAREstimator
+
+warnings.warn(
+    "The module gluonts.model.deepar has been moved to "
+    "gluonts.mx.model.deepar. In GluonTS v0.12 it will be no longer "
+    "possible to use the old path. Try to use 'from gluonts.mx import "
+    "DeepAREstimator'.",
+    FutureWarning,
+)
 
 __all__ = ["DeepAREstimator"]
-
-# fix Sphinx issues, see https://bit.ly/2K2eptM
-for item in __all__:
-    if hasattr(item, "__module__"):
-        setattr(item, "__module__", __name__)
