@@ -10,7 +10,17 @@
 # on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 # express or implied. See the License for the specific language governing
 # permissions and limitations under the License.
-# Relative imports
-from ._estimator import DeepStateEstimator
+
+import warnings
+
+from gluonts.mx.model.deepstate import DeepStateEstimator
+
+warnings.warn(
+    "The module gluonts.model.deepstate has been moved to "
+    "gluonts.mx.model.deepstate. In GluonTS v0.12 it will be no longer "
+    "possible to use the old path. Try to use 'from gluonts.mx import "
+    "DeepStateEstimator'.",
+    FutureWarning,
+)
 
 __all__ = ["DeepStateEstimator"]
