@@ -11,18 +11,28 @@
 # express or implied. See the License for the specific language governing
 # permissions and limitations under the License.
 
-# Relative imports
-from ._estimator import (
+import warnings
+
+from gluonts.mx.model.deepvar_hierarchical import (
     constraint_mat,
     null_space_projection_mat,
     DeepVARHierarchicalEstimator,
+    reconcile_samples,
+    coherency_error,
+)
+
+warnings.warn(
+    "The module gluonts.model.deepvar_hierarchical has been moved to "
+    "gluonts.mx.model.deepvar_hierarchical. In GluonTS v0.12 it will be no "
+    "longer possible to use the old path. Try to use 'from gluonts.mx import "
+    "DeepVARHierarchicalEstimator'.",
+    FutureWarning,
 )
-from ._network import reconcile_samples, reconciliation_error
 
 __all__ = [
     "DeepVARHierarchicalEstimator",
     "constraint_mat",
     "null_space_projection_mat",
     "reconcile_samples",
-    "reconciliation_error",
+    "coherency_error",
 ]
