@@ -341,14 +341,14 @@ class Forecast:
         **kwargs,
     ):
         """
-        Plots the median of the forecast as well as confidence bounds.
+        Plots the median of the forecast as well as prediction interval bounds
         (requires matplotlib and pandas).
 
         Parameters
         ----------
         prediction_intervals : float or list of floats in [0, 100]
-            Confidence interval size(s). If a list, it will stack the error
-            plots for each confidence interval. Only relevant for error styles
+            Prediction interval size(s). If a list, it will stack the error
+            plots for each prediction interval. Only relevant for error styles
             with "ci" in the name.
         show_mean : boolean
             Whether to also show the mean of the forecast.
@@ -636,11 +636,14 @@ class SampleForecast(Forecast):
             ]
         )
 
-    def to_quantile_forecast(
-        self, quantiles: List[Union[float, str]]
-    ) -> "QuantileForecast":
+    def to_quantile_forecast(self, quantiles: List[str]) -> "QuantileForecast":
         return QuantileForecast(
-            forecast_arrays=np.array([self.quantile(q) for q in quantiles]),
+            forecast_arrays=np.array(
+                [
+                    self.quantile(q) if q != "mean" else self.mean()
+                    for q in quantiles
+                ]
+            ),
             start_date=self.start_date,
             forecast_keys=quantiles,
             item_id=self.item_id,
@@ -776,14 +779,11 @@ class QuantileForecast(Forecast):
             keys = self.forecast_keys
 
         for k, v in zip(keys, self.forecast_array):
-            plt.plot(
-                self.index,
-                v,
+            pd.Series(data=v, index=self.index.to_timestamp()).plot(
                 label=f"{label_prefix}q{k}",
                 *args,
                 **kwargs,
             )
-            plt.legend()
         if output_file:
             plt.savefig(output_file)
 
