@@ -15,8 +15,3 @@ from ._estimator import NPTSEstimator
 from ._predictor import KernelType, NPTSPredictor
 
 __all__ = ["KernelType", "NPTSEstimator", "NPTSPredictor"]
-
-# fix Sphinx issues, see https://bit.ly/2K2eptM
-for item in __all__:
-    if hasattr(item, "__module__"):
-        setattr(item, "__module__", __name__)
