@@ -11,12 +11,16 @@
 # express or implied. See the License for the specific language governing
 # permissions and limitations under the License.
 
-# Relative imports
-from ._estimator import SimpleFeedForwardEstimator
+import warnings
+
+from gluonts.mx.model.simple_feedforward import SimpleFeedForwardEstimator
+
+warnings.warn(
+    "The module gluonts.model.simple_feedforward has been moved to "
+    "gluonts.mx.model.simple_feedforward. In GluonTS v0.12 it will be no "
+    "longer possible to use the old path. Try to use 'from gluonts.mx import "
+    "SimpleFeedForwardEstimator'.",
+    FutureWarning,
+)
 
 __all__ = ["SimpleFeedForwardEstimator"]
-
-# fix Sphinx issues, see https://bit.ly/2K2eptM
-for item in __all__:
-    if hasattr(item, "__module__"):
-        setattr(item, "__module__", __name__)
