@@ -11,13 +11,17 @@
 # express or implied. See the License for the specific language governing
 # permissions and limitations under the License.
 
-from ._estimator import TemporalFusionTransformerEstimator
+import warnings
+
+from gluonts.mx.model.tft import TemporalFusionTransformerEstimator
+
+warnings.warn(
+    "The module gluonts.model.tft has been moved to gluonts.mx.model.tft. "
+    "In GluonTS v0.12 it will be no longer possible to use the old path. "
+    "Try to use 'from gluonts.mx import TemporalFusionTransformerEstimator'.",
+    FutureWarning,
+)
 
 __all__ = [
     "TemporalFusionTransformerEstimator",
 ]
-
-# fix Sphinx issues, see https://bit.ly/2K2eptM
-for item in __all__:
-    if hasattr(item, "__module__"):
-        setattr(item, "__module__", __name__)
