@@ -11,18 +11,23 @@
 # express or implied. See the License for the specific language governing
 # permissions and limitations under the License.
 
-from .forecast import PointProcessSampleForecast
-from .predictor import PointProcessGluonPredictor
-from .deeptpp import DeepTPPEstimator
+import warnings
+
+from gluonts.mx.model.tpp import (
+    PointProcessSampleForecast,
+    PointProcessGluonPredictor,
+    DeepTPPEstimator,
+)
+
+warnings.warn(
+    "The module gluonts.model.tpp has been moved to gluonts.mx.model.tpp. "
+    "In GluonTS v0.12 it will be no longer possible to use the old path. "
+    "Try to use 'from gluonts.mx import DeepTPPEstimator'.",
+    FutureWarning,
+)
 
 __all__ = [
     "PointProcessGluonPredictor",
     "PointProcessSampleForecast",
     "DeepTPPEstimator",
 ]
-
-
-# fix Sphinx issues, see https://bit.ly/2K2eptM
-for item in __all__:
-    if hasattr(item, "__module__"):
-        setattr(item, "__module__", __name__)
