@@ -11,10 +11,11 @@
 # express or implied. See the License for the specific language governing
 # permissions and limitations under the License.
 
-# Standard library imports
 import os
 from pathlib import Path
 
+from .dyn import install_and_restart
+
 
 class ServePaths:
     def __init__(self, base: Path = Path("/opt/ml")) -> None:
@@ -33,3 +34,9 @@ class ServeEnv:
         self.sagemaker_batch = (
             os.environ.get("SAGEMAKER_BATCH", "false") == "true"
         )
+
+    def install_dynamic(self):
+        code = self.path.model / "code"
+
+        if code.is_dir():
+            install_and_restart(code, self.path.base / "code")
