@@ -20,7 +20,7 @@ from gluonts.core import fqname_for
 from gluonts.core.serde import dump_code
 from gluonts.dataset.common import Dataset
 from gluonts.evaluation import Evaluator, backtest
-from gluonts.model.estimator import Estimator
+from gluonts.model.estimator import Estimator, IncrementallyTrainable
 from gluonts.model.forecast import Quantile
 from gluonts.model.predictor import Predictor
 from gluonts.itertools import maybe_len
@@ -69,6 +69,7 @@ def run_train_and_test(
             train_dataset=env.datasets["train"],
             validation_dataset=env.datasets.get("validation"),
             hyperparameters=env.hyperparameters,
+            from_predictor=env.datasets.get("model"),
         )
 
     predictor.serialize(env.path.model)
@@ -82,6 +83,7 @@ def run_train(
     train_dataset: Dataset,
     hyperparameters: dict,
     validation_dataset: Optional[Dataset],
+    from_predictor: Optional[Predictor],
 ) -> Predictor:
     num_workers = (
         int(hyperparameters["num_workers"])
@@ -99,6 +101,21 @@ def run_train(
         else None
     )
 
+    if from_predictor is not None:
+        assert isinstance(forecaster, IncrementallyTrainable), (
+            "The model provided does not implement the "
+            "IncrementallyTrainable protocol"
+        )
+        return invoke_with(
+            forecaster.train_from,
+            from_predictor,
+            training_data=train_dataset,
+            validation_data=validation_dataset,
+            num_workers=num_workers,
+            num_prefetch=num_prefetch,
+            shuffle_buffer_length=shuffle_buffer_length,
+        )
+
     return invoke_with(
         forecaster.train,
         training_data=train_dataset,
@@ -125,7 +142,7 @@ def run_test(
 
     if len_original is not None and len_original > len_filtered:
         logger.warning(
-            "Not all time-series in the test-channel have "
+            "Not all time series in the test-channel have "
             "enough data to be used for evaluation. Proceeding with "
             f"{len_filtered}/{len_original} "
             f"(~{int(len_filtered / len_original * 100)}%) items."
