@@ -13,7 +13,9 @@
 
 import pytorch_lightning as pl
 import torch
+from torch.optim.lr_scheduler import ReduceLROnPlateau
 
+from gluonts.core.component import validated
 from gluonts.torch.modules.loss import DistributionLoss, NegativeLogLikelihood
 from gluonts.torch.util import weighted_average
 
@@ -39,14 +41,18 @@ class DeepARLightningModule(pl.LightningModule):
         Learning rate, default: ``1e-3``.
     weight_decay
         Weight decay regularization parameter, default: ``1e-8``.
+    patience
+        Patience parameter for learning rate scheduler, default: ``10``.
     """
 
+    @validated()
     def __init__(
         self,
         model: DeepARModel,
         loss: DistributionLoss = NegativeLogLikelihood(),
         lr: float = 1e-3,
         weight_decay: float = 1e-8,
+        patience: int = 10,
     ) -> None:
         super().__init__()
         self.save_hyperparameters()
@@ -54,6 +60,16 @@ class DeepARLightningModule(pl.LightningModule):
         self.loss = loss
         self.lr = lr
         self.weight_decay = weight_decay
+        self.patience = patience
+        self.example_input_array = tuple(
+            [
+                torch.zeros(shape, dtype=self.model.input_types()[name])
+                for (name, shape) in self.model.input_shapes().items()
+            ]
+        )
+
+    def forward(self, *args, **kwargs):
+        return self.model(*args, **kwargs)
 
     def _compute_loss(self, batch):
         feat_static_cat = batch["feat_static_cat"]
@@ -125,8 +141,21 @@ class DeepARLightningModule(pl.LightningModule):
         """
         Returns the optimizer to use.
         """
-        return torch.optim.Adam(
+        optimizer = torch.optim.Adam(
             self.model.parameters(),
             lr=self.lr,
             weight_decay=self.weight_decay,
         )
+
+        return {
+            "optimizer": optimizer,
+            "lr_scheduler": {
+                "scheduler": ReduceLROnPlateau(
+                    optimizer=optimizer,
+                    mode="min",
+                    factor=0.5,
+                    patience=self.patience,
+                ),
+                "monitor": "train_loss",
+            },
+        }
